@@ -1,5 +1,5 @@
 import os
-from typing import Any, List, Tuple
+from typing import Any
 
 from mautrix.bridge.config import BaseBridgeConfig
 from mautrix.types import UserID
@@ -14,7 +14,7 @@ class Config(BaseBridgeConfig):
             return super().__getitem__(key)
 
     @property
-    def forbidden_defaults(self) -> List[ForbiddenDefault]:
+    def forbidden_defaults(self) -> list[ForbiddenDefault]:
         return [
             *super().forbidden_defaults,
             ForbiddenDefault(
@@ -23,7 +23,7 @@ class Config(BaseBridgeConfig):
             ForbiddenDefault("bridge.permissions", ForbiddenKey("example.com")),
         ]
 
-    def do_update(self, helper: ConfigUpdateHelper) -> None:
+    def do_update(self, helper: ConfigUpdateHelper):
         super().do_update(helper)
         copy, copy_dict, base = helper.copy, helper.copy_dict, helper.base
 
@@ -42,16 +42,23 @@ class Config(BaseBridgeConfig):
         copy("bridge.backfill.initial_limit")
         copy("bridge.backfill.invite_own_puppet")
         copy("bridge.backfill.missed_limit")
+        copy("bridge.command_prefix")
         copy("bridge.delivery_receipts")
         copy("bridge.displayname_preference")
         copy("bridge.displayname_template")
         copy("bridge.double_puppet_allow_discovery")
         copy("bridge.double_puppet_server_map")
+        copy("bridge.encryption.allow")
         copy("bridge.encryption.default")
+        copy("bridge.encryption.key_sharing.allow")
+        copy("bridge.encryption.key_sharing.require_cross_signing")
+        copy("bridge.encryption.key_sharing.require_verification")
         copy("bridge.initial_chat_sync")
         copy("bridge.invite_own_puppet_to_pm")
         copy("bridge.mute_bridging")
         copy("bridge.resend_bridge_info")
+        copy("bridge.set_topic_on_dms")
+        copy("bridge.sync_direct_chat_list")
         copy("bridge.sync_with_custom_puppets")
         copy("bridge.tag_only_on_create")
         copy("bridge.temporary_disconnect_notices")
@@ -66,13 +73,17 @@ class Config(BaseBridgeConfig):
 
         copy_dict("bridge.permissions")
 
-    def _get_permissions(self, key: str) -> Tuple[bool, bool, str]:
+        # Metrics
+        copy("metrics.enabled")
+        copy("metrics.listen_port")
+
+    def _get_permissions(self, key: str) -> tuple[bool, bool, str]:
         level = self["bridge.permissions"].get(key, "")
         admin = level == "admin"
         user = level == "user" or admin
         return user, admin, level
 
-    def get_permissions(self, mxid: UserID) -> Tuple[bool, bool, str]:
+    def get_permissions(self, mxid: UserID) -> tuple[bool, bool, str]:
         permissions = self["bridge.permissions"] or {}
         if mxid in permissions:
             return self._get_permissions(mxid)
