@@ -21,9 +21,7 @@ git_revision_url: Optional[str]
 if os.path.exists(".git") and shutil.which("git"):
     try:
         git_revision = run(["git", "rev-parse", "HEAD"]).strip().decode("ascii")
-        git_revision_url = (
-            f"https://github.com/sumnerevans/linkedin-matrix/commit/{git_revision}"
-        )
+        git_revision_url = f"https://gitlab.com/beeper/linkedin/-/commit/{git_revision}"
         git_revision = git_revision[:8]
     except (subprocess.SubprocessError, OSError):
         git_revision = "unknown"
@@ -41,9 +39,7 @@ else:
     git_tag = None
 
 git_tag_url = (
-    f"https://github.com/sumnerevans/linkedin-matrix/releases/tag/{git_tag}"
-    if git_tag
-    else None
+    f"https://gitlab.com/beeper/linkedin/-/releases/{git_tag}" if git_tag else None
 )
 
 if git_tag and __version__ == git_tag[1:].replace("-", ""):
